@@ -13,7 +13,8 @@ reconstruct = function(rd) {
   if (is.null(rd)) return()
 
   if (is.list(rd)) {
-    if (length(tag(rd)) && tag(rd) %in% c('\\item', '\\tabular', '\\eqn', '\\deqn', '\\link')) {
+    multi = c('\\section', '\\subsection', '\\item', '\\tabular', '\\eqn', '\\deqn', '\\link', '\\href')
+    if (length(tag(rd)) && tag(rd) %in% multi) {
       if (tag(rd) == '\\link')
         return(paste('\\link', sprintf('[%s]', attr(rd, 'Rd_option')), '{', rd, '}', sep = ""))
       if (length(rd) == 2) {
@@ -22,11 +23,16 @@ reconstruct = function(rd) {
                      '}', sep = "", collapse = ""))
       } else if (length(rd) == 0) return(tag(rd))
     }
-    special = tag(rd) == toupper(tag(rd))
-    singles = tag(rd) %in% c('\\tab', '\\cr')
-    prefix = ifelse(special, "",
-                     paste(tag(rd), ifelse(singles, "", "{"), sep = ""))
-    suffix = ifelse(special, "", ifelse(singles, "", "}"))
+
+    special = tag(rd) == toupper(tag(rd)) && tag(rd) != '\\R'
+    if (is.null(tag(rd)) || special) {
+      prefix = ""
+      suffix = ""
+    } else {
+      singles = tag(rd) %in% c('\\tab', '\\cr', '\\R', '\\dots', '\\ldots')
+      prefix = paste0(tag(rd), ifelse(singles, "", "{"))
+      suffix = ifelse(singles, "", "}")
+    }
     paste(prefix, paste(sapply(rd, reconstruct), collapse = ""), suffix,
           sep = "")
   } else {
